# Table of Contents

- [portal-faqs](<./portal-faqs.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Portal FAQs](<./Portal-FAQs.md>)
  - [1. Why should I use the SAP LeanIX Portal?](<./Portal-FAQs/1.-Why-should-I-use-the-SAP-LeanIX-Portal.md>)
  - [2. What is the main benefit of using a Portal in my company?](<./Portal-FAQs/2.-What-is-the-main-benefit-of-using-a-Portal-in-my-company.md>)
  - [3. Can I configure more than one Portal?](<./Portal-FAQs/3.-Can-I-configure-more-than-one-Portal.md>)
  - [4. How do I configure a Portal in SAP LeanIX?](<./Portal-FAQs/4.-How-do-I-configure-a-Portal-in-SAP-LeanIX.md>)
  - [5. How do I order new software on the Portal, once configured?](<./Portal-FAQs/5.-How-do-I-order-new-software-on-the-Portal-once-configured.md>)
  - [6. What do “Approval” or “Status” mean, once I ordered new software on the Portal?](<./Portal-FAQs/6.-What-do-Approval-or-Status-mean-once-I-ordered-new-software-on-the-Portal.md>)
  - [7. Can I change filters on the Portal?](<./Portal-FAQs/7.-Can-I-change-filters-on-the-Portal.md>)
  - [8. How should I configure Request links in the Portal?](<./Portal-FAQs/8.-How-should-I-configure-Request-links-in-the-Portal.md>)
  - [9. Can any Fact Sheet type be used in the Portal?](<./Portal-FAQs/9.-Can-any-Fact-Sheet-type-be-used-in-the-Portal.md>)
  - [10. How do I add or change a Portal Name?](<./Portal-FAQs/10.-How-do-I-add-or-change-a-Portal-Name.md>)
